pub struct JsonCommons {}Implementations
Sourceimpl JsonCommons
impl JsonCommons
Sourcepub fn new() -> JsonCommons
pub fn new() -> JsonCommons
Creates a new instance of JsonCommons
Example
use json_commons::JsonCommons;
let jsonc = JsonCommons::new();Sourcepub fn get_path(&self, path: &str, content: JsonValue) -> Option<JsonValue>
pub fn get_path(&self, path: &str, content: JsonValue) -> Option<JsonValue>
You can get any dotted path as an Optional
If path is not found then return is None
Sourcepub fn path_exists(&self, path: &str, content: JsonValue) -> bool
pub fn path_exists(&self, path: &str, content: JsonValue) -> bool
Check if a dotted path exists
Sourcepub fn parse_to_vec(&self, content: JsonValue) -> VecDeque<JsonValue>
pub fn parse_to_vec(&self, content: JsonValue) -> VecDeque<JsonValue>
Parse a list of JsonValue to a VecDeque<JsonValue>
Examples
Consider the following content
{
"cars": [
{
"model": "Gurgel Itaipu E400",
"color": "red"
},
{
"model": "Gurgel X15",
"color": "brown"
}
]
}You can Parse the key cars to a vec
let json = jsonc.read_str(content);
let cars = jsonc.get_path("cars", json).unwrap();
jsonc.parse_to_vec(cars); // The output is a vec of JsonValue, with len 2Sourcepub fn serialize(&self, json: JsonValue) -> String
pub fn serialize(&self, json: JsonValue) -> String
Serialize a JsonValue into a String.
Consider the following content
{
"car": {
"model": "Gurgel Itaipu E4000",
"color": "red"
}
}Output is equivalent to Javascript JSON.stringify
let serialized = jsonc.serialize(myjson);
assert_eq!("{\"car\":{\"model\":\"Gurgel Itaipu E400\",\"color\":\"red\"}}", serialized);Sourcepub fn json_from_document(&self, doc: Document) -> JsonValue
pub fn json_from_document(&self, doc: Document) -> JsonValue
Parse a Document into a JsonValue
Sourcepub fn json_from_bson(&self, bson: Bson) -> JsonValue
pub fn json_from_bson(&self, bson: Bson) -> JsonValue
Parse a Bson into a JsonValue
Sourcepub fn json_from_bson_hex(&self, bson_hex: String) -> JsonValue
pub fn json_from_bson_hex(&self, bson_hex: String) -> JsonValue
Parse a Hex String into a JsonValue
Sourcepub fn parse_to_document(&self, json: JsonValue) -> Document
pub fn parse_to_document(&self, json: JsonValue) -> Document
Parse a JsonValue into a Document
Sourcepub fn parse_to_bson(&self, json: JsonValue) -> Bson
pub fn parse_to_bson(&self, json: JsonValue) -> Bson
Parse a JsonValue into a Bson
Sourcepub fn serialize_to_bson_hex(&self, json: JsonValue) -> String
pub fn serialize_to_bson_hex(&self, json: JsonValue) -> String
Serialize a JsonValue into a Hex String.
Consider the following content
{
"car": {
"model": "Gurgel Itaipu E4000",
"color": "red"
}
}Output is a encoded Hex BSON
let bson_hex = jsonc.serialize_to_bson_hex(myjson);
assert_eq!("3c000000036361720032000000026d6f64656c001300000047757267656c2049746169707520453430300002636f6c6f720004000000726564000000", bson_hex);Auto Trait Implementations
impl Freeze for JsonCommons
impl RefUnwindSafe for JsonCommons
impl Send for JsonCommons
impl Sync for JsonCommons
impl Unpin for JsonCommons
impl UnsafeUnpin for JsonCommons
impl UnwindSafe for JsonCommons